Gaussian process regression (object) — BAGO 0.0.1 documentation

# Gaussian process regression (object)

This is an object for building Gaussian process regression model and using it for Bayesian optimization.

The object contains the following attributes:

> - `kernel`: a `sklearn.gaussian_process.kernels` object.

> - `gpr`: a `sklearn.gaussian_process.GaussianProcessRegressor` object.

> - `trainX`: a numpy array containing the training points (input).

> - `trainy`: a numpy array containing the training values (output).

> - `scaledX`: a numpy array containing the scaled training points (input).

> - `gradientPct`: a numpy array containing percentages of the strong mobile phase for gradients in the search space.

> - `gridX`: a numpy array containing the grid search space.

> - `scaler`: a `sklearn.preprocessing.StandardScaler` object.